@@ -47,7 +47,7 @@
 
 struct _GDBusObjectSkeletonPrivate
 {
-  GMutex *lock;
+  GMutex lock;
   gchar *object_path;
   GHashTable *map_name_to_iface;
 };
@@ -80,7 +80,7 @@ g_dbus_object_skeleton_finalize (GObject *_object)
   g_free (object->priv->object_path);
   g_hash_table_unref (object->priv->map_name_to_iface);
 
-  g_mutex_free (object->priv->lock);
+  g_mutex_clear (&object->priv->lock);
 
   if (G_OBJECT_CLASS (g_dbus_object_skeleton_parent_class)->finalize != NULL)
     G_OBJECT_CLASS (g_dbus_object_skeleton_parent_class)->finalize (_object);
@@ -97,9 +97,9 @@ g_dbus_object_skeleton_get_property (GObject    *_object,
   switch (prop_id)
     {
     case PROP_G_OBJECT_PATH:
-      g_mutex_lock (object->priv->lock);
+      g_mutex_lock (&object->priv->lock);
       g_value_take_string (value, object->priv->object_path);
-      g_mutex_unlock (object->priv->lock);
+      g_mutex_unlock (&object->priv->lock);
       break;
 
     default:
@@ -204,7 +204,7 @@ static void
 g_dbus_object_skeleton_init (GDBusObjectSkeleton *object)
 {
   object->priv = G_TYPE_INSTANCE_GET_PRIVATE (object, G_TYPE_DBUS_OBJECT_SKELETON, GDBusObjectSkeletonPrivate);
-  object->priv->lock = g_mutex_new ();
+  g_mutex_init (&object->priv->lock);
   object->priv->map_name_to_iface = g_hash_table_new_full (g_str_hash,
                                                            g_str_equal,
                                                            g_free,
@@ -245,18 +245,18 @@ g_dbus_object_skeleton_set_object_path (GDBusObjectSkeleton *object,
 {
   g_return_if_fail (G_IS_DBUS_OBJECT_SKELETON (object));
   g_return_if_fail (object_path == NULL || g_variant_is_object_path (object_path));
-  g_mutex_lock (object->priv->lock);
+  g_mutex_lock (&object->priv->lock);
   /* TODO: fail if object is currently exported */
   if (g_strcmp0 (object->priv->object_path, object_path) != 0)
     {
       g_free (object->priv->object_path);
       object->priv->object_path = g_strdup (object_path);
-      g_mutex_unlock (object->priv->lock);
+      g_mutex_unlock (&object->priv->lock);
       g_object_notify (G_OBJECT (object), "g-object-path");
     }
   else
     {
-      g_mutex_unlock (object->priv->lock);
+      g_mutex_unlock (&object->priv->lock);
     }
 }
 
@@ -265,9 +265,9 @@ g_dbus_object_skeleton_get_object_path (GDBusObject *_object)
 {
   GDBusObjectSkeleton *object = G_DBUS_OBJECT_SKELETON (_object);
   const gchar *ret;
-  g_mutex_lock (object->priv->lock);
+  g_mutex_lock (&object->priv->lock);
   ret = object->priv->object_path;
-  g_mutex_unlock (object->priv->lock);
+  g_mutex_unlock (&object->priv->lock);
   return ret;
 }
 
@@ -296,7 +296,7 @@ g_dbus_object_skeleton_add_interface (GDBusObjectSkeleton     *object,
   g_return_if_fail (G_IS_DBUS_OBJECT_SKELETON (object));
   g_return_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_));
 
-  g_mutex_lock (object->priv->lock);
+  g_mutex_lock (&object->priv->lock);
 
   info = g_dbus_interface_skeleton_get_info (interface_);
   g_object_ref (interface_);
@@ -312,7 +312,7 @@ g_dbus_object_skeleton_add_interface (GDBusObjectSkeleton     *object,
                        g_object_ref (interface_));
   g_dbus_interface_set_object (G_DBUS_INTERFACE (interface_), G_DBUS_OBJECT (object));
 
-  g_mutex_unlock (object->priv->lock);
+  g_mutex_unlock (&object->priv->lock);
 
   if (interface_to_remove != NULL)
     {
@@ -348,14 +348,14 @@ g_dbus_object_skeleton_remove_interface  (GDBusObjectSkeleton    *object,
   g_return_if_fail (G_IS_DBUS_OBJECT_SKELETON (object));
   g_return_if_fail (G_IS_DBUS_INTERFACE (interface_));
 
-  g_mutex_lock (object->priv->lock);
+  g_mutex_lock (&object->priv->lock);
 
   info = g_dbus_interface_skeleton_get_info (interface_);
 
   other_interface = g_hash_table_lookup (object->priv->map_name_to_iface, info->name);
   if (other_interface == NULL)
     {
-      g_mutex_unlock (object->priv->lock);
+      g_mutex_unlock (&object->priv->lock);
       g_warning ("Tried to remove interface with name %s from object "
                  "at path %s but no such interface exists",
                  info->name,
@@ -363,7 +363,7 @@ g_dbus_object_skeleton_remove_interface  (GDBusObjectSkeleton    *object,
     }
   else if (other_interface != interface_)
     {
-      g_mutex_unlock (object->priv->lock);
+      g_mutex_unlock (&object->priv->lock);
       g_warning ("Tried to remove interface %p with name %s from object "
                  "at path %s but the object has the interface %p",
                  interface_,
@@ -375,7 +375,7 @@ g_dbus_object_skeleton_remove_interface  (GDBusObjectSkeleton    *object,
     {
       g_object_ref (interface_);
       g_warn_if_fail (g_hash_table_remove (object->priv->map_name_to_iface, info->name));
-      g_mutex_unlock (object->priv->lock);
+      g_mutex_unlock (&object->priv->lock);
       g_dbus_interface_set_object (G_DBUS_INTERFACE (interface_), NULL);
       g_signal_emit_by_name (object,
                              "interface-removed",
@@ -406,13 +406,13 @@ g_dbus_object_skeleton_remove_interface_by_name (GDBusObjectSkeleton *object,
   g_return_if_fail (G_IS_DBUS_OBJECT_SKELETON (object));
   g_return_if_fail (g_dbus_is_interface_name (interface_name));
 
-  g_mutex_lock (object->priv->lock);
+  g_mutex_lock (&object->priv->lock);
   interface = g_hash_table_lookup (object->priv->map_name_to_iface, interface_name);
   if (interface != NULL)
     {
       g_object_ref (interface);
       g_warn_if_fail (g_hash_table_remove (object->priv->map_name_to_iface, interface_name));
-      g_mutex_unlock (object->priv->lock);
+      g_mutex_unlock (&object->priv->lock);
       g_dbus_interface_set_object (interface, NULL);
       g_signal_emit_by_name (object,
                              "interface-removed",
@@ -421,7 +421,7 @@ g_dbus_object_skeleton_remove_interface_by_name (GDBusObjectSkeleton *object,
     }
   else
     {
-      g_mutex_unlock (object->priv->lock);
+      g_mutex_unlock (&object->priv->lock);
     }
 }
 
@@ -435,11 +435,11 @@ g_dbus_object_skeleton_get_interface (GDBusObject  *_object,
   g_return_val_if_fail (G_IS_DBUS_OBJECT_SKELETON (object), NULL);
   g_return_val_if_fail (g_dbus_is_interface_name (interface_name), NULL);
 
-  g_mutex_lock (object->priv->lock);
+  g_mutex_lock (&object->priv->lock);
   ret = g_hash_table_lookup (object->priv->map_name_to_iface, interface_name);
   if (ret != NULL)
     g_object_ref (ret);
-  g_mutex_unlock (object->priv->lock);
+  g_mutex_unlock (&object->priv->lock);
   return ret;
 }
 
@@ -453,10 +453,10 @@ g_dbus_object_skeleton_get_interfaces (GDBusObject *_object)
 
   ret = NULL;
 
-  g_mutex_lock (object->priv->lock);
+  g_mutex_lock (&object->priv->lock);
   ret = g_hash_table_get_values (object->priv->map_name_to_iface);
   g_list_foreach (ret, (GFunc) g_object_ref, NULL);
-  g_mutex_unlock (object->priv->lock);
+  g_mutex_unlock (&object->priv->lock);
 
   return ret;
 }
@@ -476,10 +476,10 @@ g_dbus_object_skeleton_flush (GDBusObjectSkeleton *object)
 {
   GList *to_flush, *l;
 
-  g_mutex_lock (object->priv->lock);
+  g_mutex_lock (&object->priv->lock);
   to_flush = g_hash_table_get_values (object->priv->map_name_to_iface);
   g_list_foreach (to_flush, (GFunc) g_object_ref, NULL);
-  g_mutex_unlock (object->priv->lock);
+  g_mutex_unlock (&object->priv->lock);
 
   for (l = to_flush; l != NULL; l = l->next)
     g_dbus_interface_skeleton_flush (G_DBUS_INTERFACE_SKELETON (l->data));
