@@ -34,7 +34,7 @@ G_BEGIN_DECLS
 
 #define G_TYPE_DRIVE           (g_drive_get_type ())
 #define G_DRIVE(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), G_TYPE_DRIVE, GDrive))
-#define G_IS_DRIVE(obj)	       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_TYPE_DRIVE))
+#define G_IS_DRIVE(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_TYPE_DRIVE))
 #define G_DRIVE_GET_IFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), G_TYPE_DRIVE, GDriveIface))
 
 /**
@@ -65,9 +65,13 @@ G_BEGIN_DECLS
  * @stop: Stops a #GDrive. Since 2.22.
  * @stop_finish: Finishes a stop operation. Since 2.22.
  * @can_start: Returns %TRUE if a #GDrive can be started. Since 2.22.
+ * @can_start_degraded: Returns %TRUE if a #GDrive can be started degraded. Since 2.22.
  * @start: Starts a #GDrive. Since 2.22.
  * @start_finish: Finishes a start operation. Since 2.22.
  * @stop_button: Signal emitted when the physical stop button (if any) of a drive have been pressed. Since 2.22.
+ * @eject_with_operation: Starts ejecting a #GDrive using a #GMountOperation. Since 2.22.
+ * @eject_with_operation_finish: Finishes an eject operation using a #GMountOperation. Since 2.22.
+ * @get_sort_key: Gets a key used for sorting #GDrive instances or %NULL if no such key exists. Since 2.32.
  *
  * Interface for creating #GDrive implementations.
  */
@@ -115,9 +119,10 @@ struct _GDriveIface
   GDriveStartStopType (* get_start_stop_type) (GDrive        *drive);
 
   gboolean (* can_start)                (GDrive              *drive);
+  gboolean (* can_start_degraded)       (GDrive              *drive);
   void     (* start)                    (GDrive              *drive,
                                          GDriveStartFlags     flags,
-                                         GMountOperation     *start_operation,
+                                         GMountOperation     *mount_operation,
                                          GCancellable        *cancellable,
                                          GAsyncReadyCallback  callback,
                                          gpointer             user_data);
@@ -128,6 +133,7 @@ struct _GDriveIface
   gboolean (* can_stop)                 (GDrive              *drive);
   void     (* stop)                     (GDrive              *drive,
                                          GMountUnmountFlags   flags,
+                                         GMountOperation     *mount_operation,
                                          GCancellable        *cancellable,
                                          GAsyncReadyCallback  callback,
                                          gpointer             user_data);
@@ -137,6 +143,17 @@ struct _GDriveIface
   /* signal, not VFunc */
   void     (* stop_button)              (GDrive              *drive);
 
+  void        (* eject_with_operation)      (GDrive              *drive,
+                                             GMountUnmountFlags   flags,
+                                             GMountOperation     *mount_operation,
+                                             GCancellable        *cancellable,
+                                             GAsyncReadyCallback  callback,
+                                             gpointer             user_data);
+  gboolean    (* eject_with_operation_finish) (GDrive            *drive,
+                                             GAsyncResult        *result,
+                                             GError             **error);
+
+  const gchar * (* get_sort_key)        (GDrive              *drive);
 };
 
 GType    g_drive_get_type                 (void) G_GNUC_CONST;
@@ -150,14 +167,19 @@ gboolean g_drive_has_media                (GDrive               *drive);
 gboolean g_drive_is_media_check_automatic (GDrive               *drive);
 gboolean g_drive_can_poll_for_media       (GDrive               *drive);
 gboolean g_drive_can_eject                (GDrive               *drive);
+#ifndef G_DISABLE_DEPRECATED
+GLIB_DEPRECATED_FOR(g_drive_eject_with_operation)
 void     g_drive_eject                    (GDrive               *drive,
-					   GMountUnmountFlags    flags,
+                                           GMountUnmountFlags    flags,
                                            GCancellable         *cancellable,
                                            GAsyncReadyCallback   callback,
                                            gpointer              user_data);
+
+GLIB_DEPRECATED_FOR(g_drive_eject_with_operation_finish)
 gboolean g_drive_eject_finish             (GDrive               *drive,
                                            GAsyncResult         *result,
                                            GError              **error);
+#endif
 void     g_drive_poll_for_media           (GDrive               *drive,
                                            GCancellable         *cancellable,
                                            GAsyncReadyCallback   callback,
@@ -166,15 +188,16 @@ gboolean g_drive_poll_for_media_finish    (GDrive               *drive,
                                            GAsyncResult         *result,
                                            GError              **error);
 char *   g_drive_get_identifier           (GDrive              *drive,
-					   const char          *kind);
+                                           const char          *kind);
 char **  g_drive_enumerate_identifiers    (GDrive              *drive);
 
 GDriveStartStopType g_drive_get_start_stop_type (GDrive        *drive);
 
 gboolean g_drive_can_start                (GDrive              *drive);
+gboolean g_drive_can_start_degraded       (GDrive              *drive);
 void     g_drive_start                    (GDrive              *drive,
                                            GDriveStartFlags     flags,
-                                           GMountOperation     *start_operation,
+                                           GMountOperation     *mount_operation,
                                            GCancellable        *cancellable,
                                            GAsyncReadyCallback  callback,
                                            gpointer             user_data);
@@ -184,7 +207,8 @@ gboolean g_drive_start_finish             (GDrive               *drive,
 
 gboolean g_drive_can_stop                 (GDrive               *drive);
 void     g_drive_stop                     (GDrive               *drive,
-					   GMountUnmountFlags    flags,
+                                           GMountUnmountFlags    flags,
+                                           GMountOperation      *mount_operation,
                                            GCancellable         *cancellable,
                                            GAsyncReadyCallback   callback,
                                            gpointer              user_data);
@@ -192,6 +216,18 @@ gboolean g_drive_stop_finish              (GDrive               *drive,
                                            GAsyncResult         *result,
                                            GError              **error);
 
+void        g_drive_eject_with_operation      (GDrive              *drive,
+                                               GMountUnmountFlags   flags,
+                                               GMountOperation     *mount_operation,
+                                               GCancellable        *cancellable,
+                                               GAsyncReadyCallback  callback,
+                                               gpointer             user_data);
+gboolean    g_drive_eject_with_operation_finish (GDrive            *drive,
+                                               GAsyncResult        *result,
+                                               GError             **error);
+
+const gchar *g_drive_get_sort_key         (GDrive               *drive);
+
 G_END_DECLS
 
 #endif /* __G_DRIVE_H__ */
