@@ -24,7 +24,6 @@
 
 #include "gpollableinputstream.h"
 #include "gasynchelper.h"
-#include "gio-marshal.h"
 #include "glibintl.h"
 
 /**
@@ -150,8 +149,8 @@ g_pollable_input_stream_default_read_nonblocking (GPollableInputStream  *stream,
 {
   if (!g_pollable_input_stream_is_readable (stream))
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_WOULD_BLOCK,
-		   g_strerror (EAGAIN));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_WOULD_BLOCK,
+                           g_strerror (EAGAIN));
       return -1;
     }
 
@@ -247,8 +246,8 @@ pollable_source_closure_callback (GObject  *stream,
 {
   GClosure *closure = data;
 
-  GValue param = { 0, };
-  GValue result_value = { 0, };
+  GValue param = G_VALUE_INIT;
+  GValue result_value = G_VALUE_INIT;
   gboolean result;
 
   g_value_init (&result_value, G_TYPE_BOOLEAN);
@@ -272,7 +271,7 @@ static GSourceFuncs pollable_source_funcs =
   pollable_source_dispatch,
   pollable_source_finalize,
   (GSourceFunc)pollable_source_closure_callback,
-  (GSourceDummyMarshal)_gio_marshal_BOOLEAN__VOID,
+  (GSourceDummyMarshal)g_cclosure_marshal_generic,
 };
 
 /**
