@@ -217,13 +217,15 @@ socket_strerror (int err)
 #ifndef G_OS_WIN32
   return g_strerror (err);
 #else
-  static GStaticPrivate last_msg = G_STATIC_PRIVATE_INIT;
+  const char *msg_ret;
   char *msg;
 
   msg = g_win32_error_message (err);
-  g_static_private_set (&last_msg, msg, g_free);
 
-  return msg;
+  msg_ret = g_intern_string (msg);
+  g_free (msg);
+
+  return msg_ret;
 #endif
 }
 
@@ -2534,8 +2536,8 @@ socket_source_closure_callback (GSocket      *socket,
 {
   GClosure *closure = data;
 
-  GValue params[2] = { { 0, }, { 0, } };
-  GValue result_value = { 0, };
+  GValue params[2] = { G_VALUE_INIT, G_VALUE_INIT };
+  GValue result_value = G_VALUE_INIT;
   gboolean result;
 
   g_value_init (&result_value, G_TYPE_BOOLEAN);
