@@ -101,6 +101,7 @@ G_BEGIN_DECLS
  *   it is not known.
  * @eject_with_operation: Starts ejecting a #GVolume using a #GMountOperation. Since 2.22.
  * @eject_with_operation_finish: Finishes an eject operation using a #GMountOperation. Since 2.22.
+ * @get_sort_key: Gets a key used for sorting #GVolume instance or %NULL if no such key exists. Since 2.32.
  *
  * Interface for implementing operations for mountable volumes.
  **/
@@ -159,6 +160,8 @@ struct _GVolumeIface
   gboolean    (* eject_with_operation_finish) (GVolume           *volume,
                                              GAsyncResult        *result,
                                              GError             **error);
+
+  const gchar * (* get_sort_key)        (GVolume             *volume);
 };
 
 GType    g_volume_get_type              (void) G_GNUC_CONST;
@@ -181,14 +184,17 @@ gboolean g_volume_mount_finish          (GVolume              *volume,
 					 GAsyncResult         *result,
 					 GError              **error);
 #ifndef G_DISABLE_DEPRECATED
+GLIB_DEPRECATED_FOR(g_volume_eject_with_operation)
 void     g_volume_eject                 (GVolume              *volume,
-					 GMountUnmountFlags    flags,
-					 GCancellable         *cancellable,
-					 GAsyncReadyCallback   callback,
-					 gpointer              user_data);
+                                         GMountUnmountFlags    flags,
+                                         GCancellable         *cancellable,
+                                         GAsyncReadyCallback   callback,
+                                         gpointer              user_data);
+
+GLIB_DEPRECATED_FOR(g_volume_eject_with_operation_finish)
 gboolean g_volume_eject_finish          (GVolume              *volume,
-					 GAsyncResult         *result,
-					 GError              **error);
+                                         GAsyncResult         *result,
+                                         GError              **error);
 #endif
 char *   g_volume_get_identifier        (GVolume              *volume,
 					 const char           *kind);
@@ -206,6 +212,8 @@ gboolean    g_volume_eject_with_operation_finish (GVolume          *volume,
                                                GAsyncResult        *result,
                                                GError             **error);
 
+const gchar *g_volume_get_sort_key            (GVolume              *volume);
+
 G_END_DECLS
 
 #endif /* __G_VOLUME_H__ */
