@@ -197,6 +197,7 @@ test_delivery_in_thread_func (gpointer _data)
                                                         "NameOwnerChanged",      /* member */
                                                         "/org/freedesktop/DBus", /* path */
                                                         NULL,
+                                                        G_DBUS_SIGNAL_FLAGS_NONE,
                                                         signal_handler,
                                                         &data,
                                                         NULL);
@@ -228,16 +229,11 @@ test_delivery_in_thread_func (gpointer _data)
 static void
 test_delivery_in_thread (void)
 {
-  GError *error;
   GThread *thread;
 
-  error = NULL;
-  thread = g_thread_create (test_delivery_in_thread_func,
-                            NULL,
-                            TRUE,
-                            &error);
-  g_assert_no_error (error);
-  g_assert (thread != NULL);
+  thread = g_thread_new ("deliver",
+                         test_delivery_in_thread_func,
+                         NULL);
 
   /* run the event loop - it is needed to dispatch D-Bus messages */
   g_main_loop_run (loop);
@@ -378,12 +374,10 @@ test_method_calls_on_proxy (GDBusProxy *proxy)
       SyncThreadData data1;
       SyncThreadData data2;
       SyncThreadData data3;
-      GError *error;
       GTimeVal start_time;
       GTimeVal end_time;
       guint elapsed_msec;
 
-      error = NULL;
       do_async = (n == 0);
 
       g_get_current_time (&start_time);
@@ -393,36 +387,27 @@ test_method_calls_on_proxy (GDBusProxy *proxy)
       data1.num = 100;
       data1.async = do_async;
       data1.done = FALSE;
-      thread1 = g_thread_create (test_sleep_in_thread_func,
-                                 &data1,
-                                 TRUE,
-                                 &error);
-      g_assert_no_error (error);
-      g_assert (thread1 != NULL);
+      thread1 = g_thread_new ("sleep",
+                              test_sleep_in_thread_func,
+                              &data1);
 
       data2.proxy = proxy;
       data2.msec = 20;
       data2.num = 200;
       data2.async = do_async;
       data2.done = FALSE;
-      thread2 = g_thread_create (test_sleep_in_thread_func,
-                                 &data2,
-                                 TRUE,
-                                 &error);
-      g_assert_no_error (error);
-      g_assert (thread2 != NULL);
+      thread2 = g_thread_new ("sleep2",
+                              test_sleep_in_thread_func,
+                              &data2);
 
       data3.proxy = proxy;
       data3.msec = 100;
       data3.num = 40;
       data3.async = do_async;
       data3.done = FALSE;
-      thread3 = g_thread_create (test_sleep_in_thread_func,
-                                 &data3,
-                                 TRUE,
-                                 &error);
-      g_assert_no_error (error);
-      g_assert (thread3 != NULL);
+      thread3 = g_thread_new ("sleep3",
+                              test_sleep_in_thread_func,
+                              &data3);
 
       /* we handle messages in the main loop - threads will quit it when they are done */
       while (!(data1.done && data2.done && data3.done))
@@ -493,7 +478,6 @@ main (int   argc,
   gint ret;
 
   g_type_init ();
-  g_thread_init (NULL);
   g_test_init (&argc, &argv, NULL);
 
   /* all the tests rely on a shared main loop */
