@@ -104,7 +104,7 @@ test_unknown_key (void)
 /* Check that we get an error when the schema
  * has not been installed
  */
-void
+static void
 test_no_schema (void)
 {
   if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDERR))
@@ -355,7 +355,7 @@ changed_cb (GSettings   *settings,
 
 /* Test that basic change notification with the changed signal works.
  */
-void
+static void
 test_changes (void)
 {
   GSettings *settings;
@@ -401,7 +401,7 @@ changed_cb2 (GSettings   *settings,
  * Also test that the has-unapplied property is properly
  * maintained.
  */
-void
+static void
 test_delay_apply (void)
 {
   GSettings *settings;
@@ -718,7 +718,7 @@ typedef struct
 
   gboolean bool_prop;
   gboolean anti_bool_prop;
-  gchar byte_prop;
+  gint8 byte_prop;
   gint int16_prop;
   guint16 uint16_prop;
   gint int_prop;
@@ -738,6 +738,7 @@ typedef struct
   GObjectClass parent_class;
 } TestObjectClass;
 
+static GType test_object_get_type (void);
 G_DEFINE_TYPE (TestObject, test_object, G_TYPE_OBJECT)
 
 static void
@@ -771,7 +772,7 @@ test_object_get_property (GObject    *object,
       g_value_set_boolean (value, test_object->anti_bool_prop);
       break;
     case PROP_BYTE:
-      g_value_set_char (value, test_object->byte_prop);
+      g_value_set_schar (value, test_object->byte_prop);
       break;
     case PROP_UINT16:
       g_value_set_uint (value, test_object->uint16_prop);
@@ -829,7 +830,7 @@ test_object_set_property (GObject      *object,
       test_object->anti_bool_prop = g_value_get_boolean (value);
       break;
     case PROP_BYTE:
-      test_object->byte_prop = g_value_get_char (value);
+      test_object->byte_prop = g_value_get_schar (value);
       break;
     case PROP_INT16:
       test_object->int16_prop = g_value_get_int (value);
@@ -1887,31 +1888,6 @@ test_get_range (void)
   g_object_unref (settings);
 }
 
-static gboolean
-ignore_criticals (const gchar    *log_domain,
-                  GLogLevelFlags  log_level,
-                  const gchar    *message,
-                  gpointer        user_data)
-{
-  return (log_level & G_LOG_LEVEL_MASK) != G_LOG_LEVEL_CRITICAL;
-}
-
-static void
-test_missing_schema (void)
-{
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDERR))
-    {
-      GSettings *settings;
-
-      g_test_log_set_fatal_handler (ignore_criticals, NULL);
-      settings = g_settings_new ("schema.does.not.exist");
-      g_settings_get_value (settings, "some-key");
-      g_error ("i'm doing science and i'm still alive");
-    }
-  g_test_trap_assert_failed ();
-  g_test_trap_assert_stderr ("*still alive*");
-}
-
 int
 main (int argc, char *argv[])
 {
@@ -1996,7 +1972,6 @@ main (int argc, char *argv[])
   g_test_add_func ("/gsettings/list-schemas", test_list_schemas);
   g_test_add_func ("/gsettings/mapped", test_get_mapped);
   g_test_add_func ("/gsettings/get-range", test_get_range);
-  g_test_add_func ("/gsettings/missing-schema", test_missing_schema);
 
   result = g_test_run ();
 
