@@ -37,6 +37,7 @@
 #include "gdataset.h"
 #include "gbitlock.h"
 
+#include "gslice.h"
 #include "gdatasetprivate.h"
 #include "ghash.h"
 #include "gquark.h"
@@ -827,8 +828,8 @@ g_datalist_id_get_data (GData	 **datalist,
 
 /**
  * g_datalist_get_data:
- * @dl: a datalist.
- * @k: the string identifying a data element.
+ * @datalist: a datalist.
+ * @key: the string identifying a data element.
  * @Returns: the data element, or %NULL if it is not found.
  *
  * Gets a data element, using its string identifer. This is slower than
@@ -1091,7 +1092,7 @@ g_data_initialize (void)
  * g_intern_static_string(). An interned string is a canonical
  * representation for a string. One important advantage of interned
  * strings is that they can be compared for equality by a simple
- * pointer comparision, rather than using strcmp().
+ * pointer comparison, rather than using strcmp().
  **/
 
 /**
@@ -1103,7 +1104,7 @@ g_data_initialize (void)
 
 /**
  * g_quark_try_string:
- * @string: a string.
+ * @string: (allow-none): a string.
  * @Returns: the #GQuark associated with the string, or 0 if @string is
  *           %NULL or there is no #GQuark associated with it.
  *
@@ -1182,7 +1183,7 @@ g_quark_from_string_internal (const gchar *string,
 
 /**
  * g_quark_from_string:
- * @string: a string.
+ * @string: (allow-none): a string.
  * @Returns: the #GQuark identifying the string, or 0 if @string is
  *           %NULL.
  *
@@ -1207,7 +1208,7 @@ g_quark_from_string (const gchar *string)
 
 /**
  * g_quark_from_static_string:
- * @string: a string.
+ * @string: (allow-none): a string.
  * @Returns: the #GQuark identifying the string, or 0 if @string is
  *           %NULL.
  *
@@ -1298,7 +1299,7 @@ g_quark_new (gchar *string)
 
 /**
  * g_intern_string:
- * @string: a string
+ * @string: (allow-none): a string
  * 
  * Returns a canonical representation for @string. Interned strings can
  * be compared for equality by comparing the pointers, instead of using strcmp().
@@ -1326,7 +1327,7 @@ g_intern_string (const gchar *string)
 
 /**
  * g_intern_static_string:
- * @string: a static string
+ * @string: (allow-none): a static string
  * 
  * Returns a canonical representation for @string. Interned strings can
  * be compared for equality by comparing the pointers, instead of using strcmp().
