@@ -60,10 +60,10 @@
 
 #include "gdatetime.h"
 
+#include "gslice.h"
 #include "gatomic.h"
 #include "gfileutils.h"
 #include "ghash.h"
-#include "giochannel.h"
 #include "gmain.h"
 #include "gmappedfile.h"
 #include "gstrfuncs.h"
@@ -76,9 +76,6 @@
 #ifndef G_OS_WIN32
 #include <sys/time.h>
 #include <time.h>
-#ifdef HAVE_TIMERFD
-#include <sys/timerfd.h>
-#endif
 #endif /* !G_OS_WIN32 */
 
 /**
@@ -176,8 +173,11 @@ static const guint16 days_in_year[2][13] =
                      nl_langinfo (AM_STR) : \
                      nl_langinfo (PM_STR))
 
+#define PREFERRED_DATE_TIME_FMT nl_langinfo (D_T_FMT)
 #define PREFERRED_DATE_FMT nl_langinfo (D_FMT)
 #define PREFERRED_TIME_FMT nl_langinfo (T_FMT)
+#define PREFERRED_TIME_FMT nl_langinfo (T_FMT)
+#define PREFERRED_12HR_TIME_FMT nl_langinfo (T_FMT_AMPM)
 
 static const gint weekday_item[2][7] =
 {
@@ -200,9 +200,12 @@ static const gint month_item[2][12] =
 
 #define GET_AMPM(d)          ((g_date_time_get_hour (d) < 12)  \
                                        /* Translators: 'before midday' indicator */ \
-                                ? C_("GDateTime", "am") \
+                                ? C_("GDateTime", "AM") \
                                   /* Translators: 'after midday' indicator */ \
-                                : C_("GDateTime", "pm"))
+                                : C_("GDateTime", "PM"))
+
+/* Translators: this is the preferred format for expressing the date and the time */
+#define PREFERRED_DATE_TIME_FMT C_("GDateTime", "%a %b %e %H:%M:%S %Y")
 
 /* Translators: this is the preferred format for expressing the date */
 #define PREFERRED_DATE_FMT C_("GDateTime", "%m/%d/%y")
@@ -210,6 +213,8 @@ static const gint month_item[2][12] =
 /* Translators: this is the preferred format for expressing the time */
 #define PREFERRED_TIME_FMT C_("GDateTime", "%H:%M:%S")
 
+/* Translators: this is the preferred format for expressing 12 hour time */
+#define PREFERRED_12HR_TIME_FMT C_("GDateTime", "%I:%M:%S %p")
 
 #define WEEKDAY_ABBR(d)       (get_weekday_name_abbr (g_date_time_get_day_of_week (d)))
 #define WEEKDAY_FULL(d)       (get_weekday_name (g_date_time_get_day_of_week (d)))
@@ -2076,42 +2081,61 @@ g_date_time_to_utc (GDateTime *datetime)
 /* Format {{{1 */
 
 static void
-get_numeric_format (gchar    *fmt,
-                    gsize     len,
-                    gboolean  alt_digits,
-                    gchar     pad,
-                    gint      width)
+format_number (GString  *str,
+               gboolean  use_alt_digits,
+               gchar     pad,
+               gint      width,
+               guint32   number)
 {
-  const gchar *width_str;
+  const gunichar ascii_digits[10] = {
+    '0', '1', '2', '3', '4', '5', '6', '7', '8', '9'
+  };
+  const gunichar *digits = ascii_digits;
+  gunichar tmp[10];
+  gint i = 0;
 
-  if (pad == 0)
-    width_str = "";
-  else
+  g_return_if_fail (width <= 10);
+
+#ifdef HAVE_LANGINFO_OUTDIGIT
+  if (use_alt_digits)
     {
-      switch (width)
-        {
-        case 0:
-          width_str = "";
-          break;
-        default:
-          g_warning ("get_numeric_format: width %d not handled", width);
-          /* fall thru */
-        case 2:
-          if (pad == '0')
-            width_str = "02";
-          else
-            width_str = "2";
-          break;
-        case 3:
-          if (pad == '0')
-            width_str = "03";
-          else
-            width_str = "3";
-          break;
-        }
-    }
+      static gunichar alt_digits[10];
+      static gsize initialised;
+      /* 2^32 has 10 digits */
 
-  g_snprintf (fmt, len, "%%%s%sd", alt_digits ? "I": "", width_str);
+      if G_UNLIKELY (g_once_init_enter (&initialised))
+        {
+#define DO_DIGIT(n) \
+      {                                                                     \
+        union { guint integer; char *pointer; } val;                        \
+        val.pointer = nl_langinfo (_NL_CTYPE_OUTDIGIT## n ##_WC);           \
+        alt_digits[n] = val.integer;                                        \
+      }
+          DO_DIGIT(0); DO_DIGIT(1); DO_DIGIT(2); DO_DIGIT(3); DO_DIGIT(4);
+          DO_DIGIT(5); DO_DIGIT(6); DO_DIGIT(7); DO_DIGIT(8); DO_DIGIT(9);
+#undef DO_DIGIT
+          g_once_init_leave (&initialised, TRUE);
+        }
+
+      digits = alt_digits;
+    }
+#endif /* HAVE_LANGINFO_OUTDIGIT */
+
+  do
+    {
+      tmp[i++] = digits[number % 10];
+      number /= 10;
+    }
+  while (number);
+
+  while (pad && i < width)
+    tmp[i++] = pad == '0' ? digits[0] : pad;
+
+  /* should really be impossible */
+  g_assert (i <= 10);
+
+  while (i)
+    g_string_append_unichar (str, tmp[--i]);
 }
 
 /**
@@ -2123,189 +2147,221 @@ get_numeric_format (gchar    *fmt,
  * Creates a newly allocated string representing the requested @format.
  *
  * The format strings understood by this function are a subset of the
- * strftime() format language. In contrast to strftime(), this function
- * always produces a UTF-8 string, regardless of the current locale.
- * Note that the rendering of many formats is locale-dependent and may
- * not match the strftime() output exactly.
+ * strftime() format language as specified by C99.  The \%D, \%U and \%W
+ * conversions are not supported, nor is the 'E' modifier.  The GNU
+ * extensions \%k, \%l, \%s and \%P are supported, however, as are the
+ * '0', '_' and '-' modifiers.
+ *
+ * In contrast to strftime(), this function always produces a UTF-8
+ * string, regardless of the current locale.  Note that the rendering of
+ * many formats is locale-dependent and may not match the strftime()
+ * output exactly.
  *
  * The following format specifiers are supported:
  *
  * <variablelist>
  *  <varlistentry><term>
- *    <literal>%%a</literal>:
+ *    <literal>\%a</literal>:
  *   </term><listitem><simpara>
  *    the abbreviated weekday name according to the current locale
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%A</literal>:
+ *    <literal>\%A</literal>:
  *   </term><listitem><simpara>
  *    the full weekday name according to the current locale
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%b</literal>:
+ *    <literal>\%b</literal>:
  *   </term><listitem><simpara>
  *    the abbreviated month name according to the current locale
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%B</literal>:
+ *    <literal>\%B</literal>:
  *   </term><listitem><simpara>
  *    the full month name according to the current locale
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%d</literal>:
+ *    <literal>\%c</literal>:
+ *   </term><listitem><simpara>
+ *    the  preferred  date  and  time  representation  for the current locale
+ *  </simpara></listitem></varlistentry>
+ *  <varlistentry><term>
+ *    <literal>\%C</literal>:
+ *   </term><listitem><simpara>
+ *    The century number (year/100) as a 2-digit integer (00-99)
+ *  </simpara></listitem></varlistentry>
+ *  <varlistentry><term>
+ *    <literal>\%d</literal>:
  *   </term><listitem><simpara>
  *    the day of the month as a decimal number (range 01 to 31)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%e</literal>:
+ *    <literal>\%e</literal>:
  *   </term><listitem><simpara>
  *    the day of the month as a decimal number (range  1 to 31)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%F</literal>:
+ *    <literal>\%F</literal>:
  *   </term><listitem><simpara>
- *    equivalent to <literal>%%Y-%%m-%%d</literal> (the ISO 8601 date
+ *    equivalent to <literal>\%Y-\%m-\%d</literal> (the ISO 8601 date
  *    format)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%h</literal>:
+ *    <literal>\%g</literal>:
  *   </term><listitem><simpara>
- *    equivalent to <literal>%%b</literal>
+ *    the last two digits of the ISO 8601 week-based year as a decimal
+ *    number (00-99).  This works well with \%V and \%u.
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%H</literal>:
+ *    <literal>\%G</literal>:
+ *   </term><listitem><simpara>
+ *    the ISO 8601 week-based year as a decimal number.  This works well
+ *    with \%V and \%u.
+ *  </simpara></listitem></varlistentry>
+ *  <varlistentry><term>
+ *    <literal>\%h</literal>:
+ *   </term><listitem><simpara>
+ *    equivalent to <literal>\%b</literal>
+ *  </simpara></listitem></varlistentry>
+ *  <varlistentry><term>
+ *    <literal>\%H</literal>:
  *   </term><listitem><simpara>
  *    the hour as a decimal number using a 24-hour clock (range 00 to
  *    23)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%I</literal>:
+ *    <literal>\%I</literal>:
  *   </term><listitem><simpara>
  *    the hour as a decimal number using a 12-hour clock (range 01 to
  *    12)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%j</literal>:
+ *    <literal>\%j</literal>:
  *   </term><listitem><simpara>
  *    the day of the year as a decimal number (range 001 to 366)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%k</literal>:
+ *    <literal>\%k</literal>:
  *   </term><listitem><simpara>
  *    the hour (24-hour clock) as a decimal number (range 0 to 23);
  *    single digits are preceded by a blank
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%l</literal>:
+ *    <literal>\%l</literal>:
  *   </term><listitem><simpara>
  *    the hour (12-hour clock) as a decimal number (range 1 to 12);
  *    single digits are preceded by a blank
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%m</literal>:
+ *    <literal>\%m</literal>:
  *   </term><listitem><simpara>
  *    the month as a decimal number (range 01 to 12)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%M</literal>:
+ *    <literal>\%M</literal>:
  *   </term><listitem><simpara>
  *    the minute as a decimal number (range 00 to 59)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%N</literal>:
- *   </term><listitem><simpara>
- *    the micro-seconds as a decimal number
- *  </simpara></listitem></varlistentry>
- *  <varlistentry><term>
- *    <literal>%%p</literal>:
+ *    <literal>\%p</literal>:
  *   </term><listitem><simpara>
  *    either "AM" or "PM" according to the given time value, or the
  *    corresponding  strings for the current locale.  Noon is treated as
  *    "PM" and midnight as "AM".
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%P</literal>:
+ *    <literal>\%P</literal>:
  *   </term><listitem><simpara>
- *    like %%p but lowercase: "am" or "pm" or a corresponding string for
+ *    like \%p but lowercase: "am" or "pm" or a corresponding string for
  *    the current locale
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%r</literal>:
+ *    <literal>\%r</literal>:
  *   </term><listitem><simpara>
  *    the time in a.m. or p.m. notation
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%R</literal>:
+ *    <literal>\%R</literal>:
  *   </term><listitem><simpara>
- *    the time in 24-hour notation (<literal>%%H:%%M</literal>)
+ *    the time in 24-hour notation (<literal>\%H:\%M</literal>)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%s</literal>:
+ *    <literal>\%s</literal>:
  *   </term><listitem><simpara>
  *    the number of seconds since the Epoch, that is, since 1970-01-01
  *    00:00:00 UTC
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%S</literal>:
+ *    <literal>\%S</literal>:
  *   </term><listitem><simpara>
  *    the second as a decimal number (range 00 to 60)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%t</literal>:
+ *    <literal>\%t</literal>:
  *   </term><listitem><simpara>
  *    a tab character
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%T</literal>:
+ *    <literal>\%T</literal>:
  *   </term><listitem><simpara>
- *    the time in 24-hour notation with seconds (<literal>%%H:%%M:%%S</literal>)
+ *    the time in 24-hour notation with seconds (<literal>\%H:\%M:\%S</literal>)
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%u</literal>:
+ *    <literal>\%u</literal>:
  *   </term><listitem><simpara>
- *    the day of the week as a decimal, range 1 to 7, Monday being 1
+ *    the ISO 8601 standard day of the week as a decimal, range 1 to 7,
+ *    Monday being 1.  This works well with \%G and \%V.
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%W</literal>:
+ *    <literal>\%V</literal>:
  *   </term><listitem><simpara>
- *    the week number of the current year as a decimal number
+ *    the ISO 8601 standard week number of the current year as a decimal
+ *    number, range 01 to 53, where week 1 is the first week that has at
+ *    least 4 days in the new year. See g_date_time_get_week_of_year().
+ *    This works well with \%G and \%u.
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%x</literal>:
+ *    <literal>\%w</literal>:
+ *   </term><listitem><simpara>
+ *    the day of the week as a decimal, range 0 to 6, Sunday being 0.
+ *    This is not the ISO 8601 standard format -- use \%u instead.
+ *  </simpara></listitem></varlistentry>
+ *  <varlistentry><term>
+ *    <literal>\%x</literal>:
  *   </term><listitem><simpara>
  *    the preferred date representation for the current locale without
  *    the time
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%X</literal>:
+ *    <literal>\%X</literal>:
  *   </term><listitem><simpara>
  *    the preferred time representation for the current locale without
  *    the date
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%y</literal>:
+ *    <literal>\%y</literal>:
  *   </term><listitem><simpara>
  *    the year as a decimal number without the century
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%Y</literal>:
+ *    <literal>\%Y</literal>:
  *   </term><listitem><simpara>
  *    the year as a decimal number including the century
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%z</literal>:
+ *    <literal>\%z</literal>:
  *   </term><listitem><simpara>
  *    the time-zone as hour offset from UTC
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%Z</literal>:
+ *    <literal>\%Z</literal>:
  *   </term><listitem><simpara>
  *    the time zone or name or abbreviation
  *  </simpara></listitem></varlistentry>
  *  <varlistentry><term>
- *    <literal>%%%</literal>:
+ *    <literal>\%\%</literal>:
  *   </term><listitem><simpara>
- *    a literal <literal>%%</literal> character
+ *    a literal <literal>\%</literal> character
  *  </simpara></listitem></varlistentry>
  * </variablelist>
  *
@@ -2361,7 +2417,6 @@ g_date_time_format (GDateTime   *datetime,
   gboolean  alt_digits = FALSE;
   gboolean  pad_set = FALSE;
   gchar     pad = '\0';
-  gchar     fmt[20];
   gchar    *ampm;
 
   g_return_val_if_fail (datetime != NULL, NULL);
@@ -2403,13 +2458,24 @@ g_date_time_format (GDateTime   *datetime,
                 case 'B':
                   g_string_append (outstr, MONTH_FULL (datetime));
                   break;
+                case 'c':
+                  {
+                    tmp = g_date_time_format (datetime, PREFERRED_DATE_TIME_FMT);
+                    g_string_append (outstr, tmp);
+                    g_free (tmp);
+                  }
+                  break;
+                case 'C':
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 2,
+                                 g_date_time_get_year (datetime) / 100);
+                  break;
                 case 'd':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, pad_set ? pad : '0', 2);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_day_of_month (datetime));
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 2,
+                                 g_date_time_get_day_of_month (datetime));
                   break;
                 case 'e':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, pad_set ? pad : 0, 2);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_day_of_month (datetime));
+                  format_number (outstr, alt_digits, pad_set ? pad : ' ', 2,
+                                 g_date_time_get_day_of_month (datetime));
                   break;
                 case 'F':
                   g_string_append_printf (outstr, "%d-%02d-%02d",
@@ -2417,49 +2483,47 @@ g_date_time_format (GDateTime   *datetime,
                                           g_date_time_get_month (datetime),
                                           g_date_time_get_day_of_month (datetime));
                   break;
+                case 'g':
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 2,
+                                 g_date_time_get_week_numbering_year (datetime) % 100);
+                  break;
+                case 'G':
+                  format_number (outstr, alt_digits, pad_set ? pad : 0, 0,
+                                 g_date_time_get_week_numbering_year (datetime));
+                  break;
                 case 'h':
                   g_string_append (outstr, MONTH_ABBR (datetime));
                   break;
                 case 'H':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, pad_set ? pad : '0', 2);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_hour (datetime));
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 2,
+                                 g_date_time_get_hour (datetime));
                   break;
                 case 'I':
-                  {
-                    gint hour = g_date_time_get_hour (datetime) % 12;
-                    if (hour == 0)
-                      hour = 12;
-                    get_numeric_format (fmt, sizeof(fmt), alt_digits, pad_set ? pad : '0', 2);
-                    g_string_append_printf (outstr, fmt, hour);
-                  }
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 2,
+                                 (g_date_time_get_hour (datetime) + 11) % 12 + 1);
                   break;
                 case 'j':
-                  get_numeric_format (fmt, sizeof(fmt), FALSE, pad_set ? pad : '0', 3);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_day_of_year (datetime));
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 3,
+                                 g_date_time_get_day_of_year (datetime));
                   break;
                 case 'k':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, pad_set ? pad : ' ', 2);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_hour (datetime));
+                  format_number (outstr, alt_digits, pad_set ? pad : ' ', 2,
+                                 g_date_time_get_hour (datetime));
                   break;
                 case 'l':
-                  {
-                    gint hour = g_date_time_get_hour (datetime) % 12;
-                    if (hour == 0)
-                      hour = 12;
-                    get_numeric_format (fmt, sizeof(fmt), alt_digits, pad_set ? pad : ' ', 2);
-                    g_string_append_printf (outstr, fmt, hour);
-                  }
+                  format_number (outstr, alt_digits, pad_set ? pad : ' ', 2,
+                                 (g_date_time_get_hour (datetime) + 11) % 12 + 1);
+                  break;
+                case 'n':
+                  g_string_append_c (outstr, '\n');
                   break;
                 case 'm':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, pad_set ? pad : '0', 2);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_month (datetime));
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 2,
+                                 g_date_time_get_month (datetime));
                   break;
                 case 'M':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, pad_set ? pad : '0', 2);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_minute (datetime));
-                  break;
-                case 'N':
-                  g_string_append_printf (outstr, "%"G_GUINT64_FORMAT, datetime->usec % USEC_PER_SECOND);
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 2,
+                                 g_date_time_get_minute (datetime));
                   break;
                 case 'O':
                   alt_digits = TRUE;
@@ -2476,16 +2540,9 @@ g_date_time_format (GDateTime   *datetime,
                   break;
                 case 'r':
                   {
-                    gint hour = g_date_time_get_hour (datetime) % 12;
-                    if (hour == 0)
-                      hour = 12;
-                    ampm = g_utf8_strup (GET_AMPM (datetime), -1);
-                    g_string_append_printf (outstr, "%02d:%02d:%02d %s",
-                                            hour,
-                                            g_date_time_get_minute (datetime),
-                                            g_date_time_get_second (datetime),
-                                            ampm);
-                    g_free (ampm);
+                    tmp = g_date_time_format (datetime, PREFERRED_12HR_TIME_FMT);
+                    g_string_append (outstr, tmp);
+                    g_free (tmp);
                   }
                   break;
                 case 'R':
@@ -2497,8 +2554,8 @@ g_date_time_format (GDateTime   *datetime,
                   g_string_append_printf (outstr, "%" G_GINT64_FORMAT, g_date_time_to_unix (datetime));
                   break;
                 case 'S':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, pad_set ? pad : '0', 2);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_second (datetime));
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 2,
+                                 g_date_time_get_second (datetime));
                   break;
                 case 't':
                   g_string_append_c (outstr, '\t');
@@ -2510,12 +2567,16 @@ g_date_time_format (GDateTime   *datetime,
                                           g_date_time_get_second (datetime));
                   break;
                 case 'u':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, 0, 0);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_day_of_week (datetime));
+                  format_number (outstr, alt_digits, 0, 0,
+                                 g_date_time_get_day_of_week (datetime));
                   break;
-                case 'W':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, 0, 0);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_day_of_year (datetime) / 7);
+                case 'V':
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 2,
+                                 g_date_time_get_week_of_year (datetime));
+                  break;
+                case 'w':
+                  format_number (outstr, alt_digits, 0, 0,
+                                 g_date_time_get_day_of_week (datetime) % 7);
                   break;
                 case 'x':
                   {
@@ -2532,12 +2593,12 @@ g_date_time_format (GDateTime   *datetime,
                   }
                   break;
                 case 'y':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, pad_set ? pad : '0', 2);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_year (datetime) % 100);
+                  format_number (outstr, alt_digits, pad_set ? pad : '0', 2,
+                                 g_date_time_get_year (datetime) % 100);
                   break;
                 case 'Y':
-                  get_numeric_format (fmt, sizeof(fmt), alt_digits, 0, 0);
-                  g_string_append_printf (outstr, fmt, g_date_time_get_year (datetime));
+                  format_number (outstr, alt_digits, 0, 0,
+                                 g_date_time_get_year (datetime));
                   break;
                 case 'z':
                   if (datetime->tz != NULL)
@@ -2558,9 +2619,6 @@ g_date_time_format (GDateTime   *datetime,
                 case '%':
                   g_string_append_c (outstr, '%');
                   break;
-                case 'n':
-                  g_string_append_c (outstr, '\n');
-                  break;
                 case '-':
                   pad_set = TRUE;
                   pad = 0;
@@ -2591,234 +2649,6 @@ bad_format:
   return NULL;
 }
 
-typedef struct _GDateTimeSource GDateTimeSource;
-struct _GDateTimeSource
-{
-  GSource     source;
-  
-  gint64      real_expiration;
-  gint64      wakeup_expiration;
-
-  gboolean    cancel_on_set;
-
-  GPollFD     pollfd;
-};
-
-static inline void
-g_datetime_source_reschedule (GDateTimeSource *datetime_source,
-			     gint64                from_monotonic)
-{
-  datetime_source->wakeup_expiration = from_monotonic + G_TIME_SPAN_SECOND;
-}
-
-static gboolean
-g_datetime_source_is_expired (GDateTimeSource *datetime_source)
-{
-  gint64 real_now;
-
-  real_now = g_get_real_time ();
-  
-  if (datetime_source->real_expiration <= real_now)
-    return TRUE;
-
-  /* We can't really detect without system support when things change;
-   * so just trigger every second.
-   */
-  if (datetime_source->cancel_on_set)
-    return TRUE;
-
-  return FALSE;
-}
-
-/* In prepare, we're just checking the monotonic time against
- * our projected wakeup.
- */
-static gboolean
-g_datetime_source_prepare (GSource *source,
-			  gint    *timeout)
-{
-  GDateTimeSource *datetime_source = (GDateTimeSource*)source;
-  gint64 monotonic_now;
-
-#ifdef HAVE_TIMERFD
-  if (datetime_source->pollfd.fd != -1)
-    {
-      *timeout = -1;
-      return FALSE;
-    }
-#endif
-
-  monotonic_now = g_source_get_time (source);
-
-  if (monotonic_now < datetime_source->wakeup_expiration)
-    {
-      /* Round up to ensure that we don't try again too early */
-      *timeout = (datetime_source->wakeup_expiration - monotonic_now + 999) / 1000;
-      return FALSE;
-    }
-
-  *timeout = 0;
-  return g_datetime_source_is_expired (datetime_source);
-}
-
-/* In check, we're looking at the wall clock.
- */
-static gboolean 
-g_datetime_source_check (GSource  *source)
-{
-  GDateTimeSource *datetime_source = (GDateTimeSource*)source;
-
-#ifdef HAVE_TIMERFD
-  if (datetime_source->pollfd.fd != -1)
-    return datetime_source->pollfd.revents != 0;
-#endif
-
-  if (g_datetime_source_is_expired (datetime_source))
-    return TRUE;
-
-  g_datetime_source_reschedule (datetime_source, g_source_get_time (source));
-  
-  return FALSE;
-}
-
-static gboolean
-g_datetime_source_dispatch (GSource    *source, 
-			   GSourceFunc callback,
-			   gpointer    user_data)
-{
-  if (!callback)
-    {
-      g_warning ("Timeout source dispatched without callback\n"
-                 "You must call g_source_set_callback().");
-      return FALSE;
-    }
-  
-  (callback) (user_data);
-
-  /* Always false as this source is documented to run once */
-  return FALSE;
-}
-
-static void
-g_datetime_source_finalize (GSource *source)
-{
-#ifdef HAVE_TIMERFD
-  GDateTimeSource *datetime_source = (GDateTimeSource*)source;
-  if (datetime_source->pollfd.fd != -1)
-    close (datetime_source->pollfd.fd);
-#endif
-}
-
-static GSourceFuncs g_datetime_source_funcs = {
-  g_datetime_source_prepare,
-  g_datetime_source_check,
-  g_datetime_source_dispatch,
-  g_datetime_source_finalize
-};
-
-#ifdef HAVE_TIMERFD
-static gboolean
-g_datetime_source_init_timerfd (GDateTimeSource *datetime_source,
-				gint64           unix_seconds)
-{
-  struct itimerspec its;
-  int settime_flags;
-
-  datetime_source->pollfd.fd = timerfd_create (CLOCK_REALTIME, TFD_CLOEXEC);
-  if (datetime_source->pollfd.fd == -1)
-    return FALSE;
-
-  memset (&its, 0, sizeof (its));
-  its.it_value.tv_sec = (time_t) unix_seconds;
-
-  /* http://article.gmane.org/gmane.linux.kernel/1132138 */
-#ifndef TFD_TIMER_CANCEL_ON_SET
-#define TFD_TIMER_CANCEL_ON_SET (1 << 1)
-#endif
-
-  settime_flags = TFD_TIMER_ABSTIME;
-  if (datetime_source->cancel_on_set)
-    settime_flags |= TFD_TIMER_CANCEL_ON_SET;
-
-  if (timerfd_settime (datetime_source->pollfd.fd, settime_flags, &its, NULL) < 0)
-    {
-      close (datetime_source->pollfd.fd);
-      datetime_source->pollfd.fd = -1;
-      return FALSE;
-    }
-
-  datetime_source->pollfd.events = G_IO_IN;
-
-  g_source_add_poll ((GSource*) datetime_source, &datetime_source->pollfd);
-
-  return TRUE;
-}
-#endif
-
-/**
- * g_date_time_source_new:
- * @datetime: Time to await
- * @cancel_on_set: Also invoke callback if the system clock changes discontiguously
- *
- * This function is designed for programs that want to schedule an
- * event based on real (wall clock) time, as returned by
- * g_get_real_time().  For example, HOUR:MINUTE wall-clock displays
- * and calendaring software.  The callback will be invoked when the
- * specified wall clock time @datetime is reached.  This includes
- * events such as the system clock being set past the given time.
- *
- * Compare versus g_timeout_source_new() which is defined to use
- * monotonic time as returned by g_get_monotonic_time().
- *
- * If @cancel_on_set is given, the callback will also be invoked at
- * most a second after the system clock is changed.  This includes
- * being set backwards or forwards, and system
- * resume from suspend.  Not all operating systems allow detecting all
- * relevant events efficiently - this function may cause the process
- * to wake up once a second in those cases.
- *
- * A wall clock display should use @cancel_on_set; a calendaring
- * program shouldn't need to.
- *
- * Note that the return value from the associated callback will be
- * ignored; this is a one time watch.
- *
- * <note><para>This function currently does not detect time zone
- * changes.  On Linux, your program should also monitor the
- * <literal>/etc/timezone</literal> file using
- * #GFileMonitor.</para></note>
-*
- * <example id="gdatetime-example-watch"><title>Clock example</title><programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" href="../../../../glib/tests/glib-clock.c"><xi:fallback>FIXME: MISSING XINCLUDE CONTENT</xi:fallback></xi:include></programlisting></example>
- *
- * Return value: A newly-constructed #GSource
- *
- * Since: 2.30
- **/
-GSource *
-g_date_time_source_new (GDateTime  *datetime,
-			gboolean    cancel_on_set)
-{
-  GDateTimeSource *datetime_source;
-  gint64 unix_seconds;
-
-  unix_seconds = g_date_time_to_unix (datetime);
-
-  datetime_source = (GDateTimeSource*) g_source_new (&g_datetime_source_funcs, sizeof (GDateTimeSource));
-
-  datetime_source->cancel_on_set = cancel_on_set;
-
-#ifdef HAVE_TIMERFD
-  if (g_datetime_source_init_timerfd (datetime_source, unix_seconds))
-    return (GSource*)datetime_source;
-  /* Fall through to non-timerfd code */
-#endif
-
-  datetime_source->real_expiration = unix_seconds * 1000000;
-  g_datetime_source_reschedule (datetime_source, g_get_monotonic_time ());
-
-  return (GSource*)datetime_source;
-}
-
 
 /* Epilogue {{{1 */
 /* vim:set foldmethod=marker: */
