@@ -37,16 +37,17 @@
 #include <glib/gbase64.h>
 #include <glib/gbitlock.h>
 #include <glib/gbookmarkfile.h>
-#include <glib/gcache.h>
+#include <glib/gcharset.h>
 #include <glib/gchecksum.h>
-#include <glib/gcompletion.h>
 #include <glib/gconvert.h>
 #include <glib/gdataset.h>
 #include <glib/gdate.h>
 #include <glib/gdatetime.h>
 #include <glib/gdir.h>
+#include <glib/genviron.h>
 #include <glib/gerror.h>
 #include <glib/gfileutils.h>
+#include <glib/ggettext.h>
 #include <glib/ghash.h>
 #include <glib/ghmac.h>
 #include <glib/ghook.h>
@@ -69,7 +70,6 @@
 #include <glib/gquark.h>
 #include <glib/gqueue.h>
 #include <glib/grand.h>
-#include <glib/grel.h>
 #include <glib/gregex.h>
 #include <glib/gscanner.h>
 #include <glib/gsequence.h>
@@ -79,11 +79,13 @@
 #include <glib/gspawn.h>
 #include <glib/gstrfuncs.h>
 #include <glib/gstring.h>
+#include <glib/gstringchunk.h>
 #include <glib/gtestutils.h>
 #include <glib/gthread.h>
 #include <glib/gthreadpool.h>
 #include <glib/gtimer.h>
 #include <glib/gtimezone.h>
+#include <glib/gtrashstack.h>
 #include <glib/gtree.h>
 #include <glib/gtypes.h>
 #include <glib/gunicode.h>
@@ -91,10 +93,19 @@
 #include <glib/gutils.h>
 #include <glib/gvarianttype.h>
 #include <glib/gvariant.h>
+#include <glib/gversion.h>
 #ifdef G_PLATFORM_WIN32
 #include <glib/gwin32.h>
 #endif
 
+#ifndef G_DISABLE_DEPRECATED
+#include <glib/deprecated/gallocator.h>
+#include <glib/deprecated/gcache.h>
+#include <glib/deprecated/gcompletion.h>
+#include <glib/deprecated/grel.h>
+#include <glib/deprecated/gthread.h>
+#endif
+
 #undef __GLIB_H_INSIDE__
 
 #endif /* __G_LIB_H__ */
