@@ -34,6 +34,7 @@
 #include "ghash.h"
 #include "gthread.h"
 #include "gbufferprivate.h"
+#include "gslice.h"
 
 /**
  * SECTION:timezone
@@ -129,9 +130,6 @@ struct _GTimeZone
   gint     ref_count;
 };
 
-G_LOCK_DEFINE_STATIC (local_timezone);
-static GTimeZone *local_timezone;
-
 G_LOCK_DEFINE_STATIC (time_zones);
 static GHashTable/*<string?, GTimeZone>*/ *time_zones;
 
@@ -155,21 +153,6 @@ again:
 
   if (ref_count == 1)
     {
-      if G_UNLIKELY (tz == local_timezone)
-        {
-          g_critical ("The last reference on the local timezone was just "
-                      "dropped, but GTimeZone itself still owns one.  This "
-                      "means that g_time_zone_unref() was called too many "
-                      "times.  Returning without lowering the refcount.");
-
-          /* We don't want to just inc this back again since if there
-           * are refcounting bugs in the code then maybe we are already
-           * at -1 and inc will just take us back to 0.  Set to 1 to be
-           * sure.
-           */
-          return;
-        }
-
       if (tz->name != NULL)
         {
           G_LOCK(time_zones);
@@ -468,12 +451,13 @@ g_time_zone_new_utc (void)
 /**
  * g_time_zone_new_local:
  *
- * Creates a #GTimeZone corresponding to local time.
+ * Creates a #GTimeZone corresponding to local time.  The local time
+ * zone may change between invocations to this function; for example,
+ * if the system administrator changes it.
  *
  * This is equivalent to calling g_time_zone_new() with the value of the
  * <varname>TZ</varname> environment variable (including the possibility
- * of %NULL).  Changes made to <varname>TZ</varname> after the first
- * call to this function may or may not be noticed by future calls.
+ * of %NULL).
  *
  * You should release the return value by calling g_time_zone_unref()
  * when you are done with it.
@@ -485,46 +469,7 @@ g_time_zone_new_utc (void)
 GTimeZone *
 g_time_zone_new_local (void)
 {
-  GTimeZone *result;
-
-  G_LOCK (local_timezone);
-  if (local_timezone == NULL)
-    local_timezone = g_time_zone_new (getenv ("TZ"));
-
-  result = g_time_zone_ref (local_timezone);
-  G_UNLOCK (local_timezone);
-
-  return result;
-}
-
-/**
- * g_time_zone_refresh_local:
- *
- * Notifies #GTimeZone that the local timezone may have changed.
- *
- * In response, #GTimeZone will drop its cache of the local time zone.
- * No existing #GTimeZone will be modified and no #GDateTime will change
- * its timezone but future calls to g_time_zone_new_local() will start
- * returning the new timezone.
- *
- * #GTimeZone does no monitoring of the local timezone on its own, which
- * is why you have to call this function to notify it of the change.
- *
- * If you use #GTimeZoneMonitor to watch for changes then this function
- * will automatically be called for you.
- **/
-void
-g_time_zone_refresh_local (void)
-{
-  GTimeZone *drop_this_ref = NULL;
-
-  G_LOCK (local_timezone);
-  drop_this_ref = local_timezone;
-  local_timezone = NULL;
-  G_UNLOCK (local_timezone);
-
-  if (drop_this_ref)
-    g_time_zone_unref (drop_this_ref);
+  return g_time_zone_new (getenv ("TZ"));
 }
 
 /* Internal helpers {{{1 */
@@ -711,7 +656,7 @@ g_time_zone_adjust_time (GTimeZone *tz,
  * Otherwise @time_ is treated is local time.  The distinction between
  * %G_TIME_TYPE_STANDARD and %G_TIME_TYPE_DAYLIGHT is ignored except in
  * the case that the given @time_ is ambiguous.  In Toronto, for example,
- * 01:30 on November 7th 2010 occured twice (once inside of daylight
+ * 01:30 on November 7th 2010 occurred twice (once inside of daylight
  * savings time and the next, an hour later, outside of daylight savings
  * time).  In this case, the different value of @type would result in a
  * different interval being returned.
