@@ -19,7 +19,7 @@
  *   Boston, MA 02111-1307, USA.
  */
 
-#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
+#if !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
 #error "Only <glib.h> can be included directly."
 #endif
 
@@ -49,8 +49,8 @@ G_BEGIN_DECLS
  * letters, prefixed by the string "U+". Leading zeros are omitted,
  * unless the code point would have fewer than four hexadecimal digits.
  * For example, "U+0041 LATIN CAPITAL LETTER A". To print a code point
- * in the U+-notation, use the format string "U+%04"G_GINT32_FORMAT"X".
- * To scan, use the format string "U+%06"G_GINT32_FORMAT"X".
+ * in the U+-notation, use the format string "U+\%04"G_GINT32_FORMAT"X".
+ * To scan, use the format string "U+\%06"G_GINT32_FORMAT"X".
  *
  * |[
  * gunichar c;
@@ -486,16 +486,8 @@ typedef enum
   G_UNICODE_SCRIPT_MANDAIC                 /* Mand */
 } GUnicodeScript;
 
-guint32 g_unicode_script_to_iso15924 (GUnicodeScript script);
-GUnicodeScript g_unicode_script_from_iso15924 (guint32 iso15924);
-
-/* Returns TRUE if current locale uses UTF-8 charset.  If CHARSET is
- * not null, sets *CHARSET to the name of the current locale's
- * charset.  This value is statically allocated, and should be copied
- * in case the locale's charset will be changed later using setlocale()
- * or in some other way.
- */
-gboolean g_get_charset (const char **charset);
+guint32        g_unicode_script_to_iso15924   (GUnicodeScript script);
+GUnicodeScript g_unicode_script_from_iso15924 (guint32        iso15924);
 
 /* These are all analogs of the <ctype.h> functions.
  */
@@ -568,6 +560,7 @@ void g_unicode_canonical_ordering (gunichar *string,
 
 #ifndef G_DISABLE_DEPRECATED
 /* Deprecated.  Use g_unichar_fully_decompose() */
+GLIB_DEPRECATED
 gunichar *g_unicode_canonical_decomposition (gunichar  ch,
                                              gsize    *result_len) G_GNUC_MALLOC;
 #endif
