@@ -188,7 +188,7 @@ gboolean ignore_test1_boolean;
 gboolean ignore_test2_boolean;
 gchar *ignore_test3_string;
 
-gchar **
+static gchar **
 split_string (const char *str, int *argc)
 {
   gchar **argv;
@@ -204,7 +204,7 @@ split_string (const char *str, int *argc)
   return argv;
 }
 
-gchar *
+static gchar *
 join_stringv (int argc, char **argv)
 {
   int i;
@@ -224,7 +224,7 @@ join_stringv (int argc, char **argv)
 }
 
 /* Performs a shallow copy */
-char **
+static char **
 copy_stringv (char **argv, int argc)
 {
   return g_memdup (argv, sizeof (char *) * (argc + 1));
@@ -256,7 +256,7 @@ error_test1_post_parse (GOptionContext *context,
   return FALSE;
 }
 
-void
+static void
 error_test1 (void)
 {
   GOptionContext *context;
@@ -317,7 +317,7 @@ error_test2_post_parse (GOptionContext *context,
   return FALSE;
 }
 
-void
+static void
 error_test2 (void)
 {
   GOptionContext *context;
@@ -378,7 +378,7 @@ error_test3_post_parse (GOptionContext *context,
   return FALSE;
 }
 
-void
+static void
 error_test3 (void)
 {
   GOptionContext *context;
@@ -415,16 +415,6 @@ error_test3 (void)
 }
 
 static void
-assert_no_error (GError *error)
-{
-  if (error) 
-    {
-      fprintf (stderr, "unexpected error: %s, %d, %s\n", g_quark_to_string (error->domain), error->code, error->message);
-      exit (1);
-    }
-}
-
-void
 arg_test1 (void)
 {
   GOptionContext *context;
@@ -443,7 +433,7 @@ arg_test1 (void)
   argv = split_string ("program --test 20 --test 30", &argc);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Last arg specified is the one that should be stored */
@@ -453,7 +443,7 @@ arg_test1 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 arg_test2 (void)
 {
   GOptionContext *context;
@@ -472,7 +462,7 @@ arg_test2 (void)
   argv = split_string ("program --test foo --test bar", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Last arg specified is the one that should be stored */
@@ -484,7 +474,7 @@ arg_test2 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 arg_test3 (void)
 {
   GOptionContext *context;
@@ -503,7 +493,7 @@ arg_test3 (void)
   argv = split_string ("program --test foo.txt", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Last arg specified is the one that should be stored */
@@ -516,7 +506,7 @@ arg_test3 (void)
 }
 
 
-void
+static void
 arg_test4 (void)
 {
   GOptionContext *context;
@@ -535,7 +525,7 @@ arg_test4 (void)
   argv = split_string ("program --test 20.0 --test 30.03", &argc);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Last arg specified is the one that should be stored */
@@ -545,7 +535,7 @@ arg_test4 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 arg_test5 (void)
 {
   GOptionContext *context;
@@ -576,7 +566,7 @@ arg_test5 (void)
     }
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Last arg specified is the one that should be stored */
@@ -590,7 +580,7 @@ arg_test5 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 arg_test6 (void)
 {
   GOptionContext *context;
@@ -610,7 +600,7 @@ arg_test6 (void)
   argv = split_string ("program --test 4294967297 --test 4294967296 --test2 0xfffffffff", &argc);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Last arg specified is the one that should be stored */
@@ -629,7 +619,7 @@ callback_parse1 (const gchar *option_name, const gchar *value,
 	return TRUE;
 }
 
-void
+static void
 callback_test1 (void)
 {
   GOptionContext *context;
@@ -648,7 +638,7 @@ callback_test1 (void)
   argv = split_string ("program --test foo.txt", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (strcmp (callback_test1_string, "foo.txt") == 0);
@@ -667,7 +657,7 @@ callback_parse2 (const gchar *option_name, const gchar *value,
 	return TRUE;
 }
 
-void
+static void
 callback_test2 (void)
 {
   GOptionContext *context;
@@ -686,7 +676,7 @@ callback_test2 (void)
   argv = split_string ("program --test --test", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (callback_test2_int == 2);
@@ -707,7 +697,7 @@ callback_parse_optional (const gchar *option_name, const gchar *value,
 	return TRUE;
 }
 
-void
+static void
 callback_test_optional_1 (void)
 {
   GOptionContext *context;
@@ -727,7 +717,7 @@ callback_test_optional_1 (void)
   argv = split_string ("program --test foo.txt", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (strcmp (callback_test_optional_string, "foo.txt") == 0);
@@ -740,7 +730,7 @@ callback_test_optional_1 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 callback_test_optional_2 (void)
 {
   GOptionContext *context;
@@ -760,7 +750,7 @@ callback_test_optional_2 (void)
   argv = split_string ("program --test", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (callback_test_optional_string == NULL);
@@ -773,7 +763,7 @@ callback_test_optional_2 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 callback_test_optional_3 (void)
 {
   GOptionContext *context;
@@ -793,7 +783,7 @@ callback_test_optional_3 (void)
   argv = split_string ("program -t foo.txt", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (strcmp (callback_test_optional_string, "foo.txt") == 0);
@@ -807,7 +797,7 @@ callback_test_optional_3 (void)
 }
 
 
-void
+static void
 callback_test_optional_4 (void)
 {
   GOptionContext *context;
@@ -827,7 +817,7 @@ callback_test_optional_4 (void)
   argv = split_string ("program -t", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (callback_test_optional_string == NULL);
@@ -840,7 +830,7 @@ callback_test_optional_4 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 callback_test_optional_5 (void)
 {
   GOptionContext *context;
@@ -862,7 +852,7 @@ callback_test_optional_5 (void)
   argv = split_string ("program --test --dummy", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (callback_test_optional_string == NULL);
@@ -875,7 +865,7 @@ callback_test_optional_5 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 callback_test_optional_6 (void)
 {
   GOptionContext *context;
@@ -897,7 +887,7 @@ callback_test_optional_6 (void)
   argv = split_string ("program -t -d", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (callback_test_optional_string == NULL);
@@ -910,7 +900,7 @@ callback_test_optional_6 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 callback_test_optional_7 (void)
 {
   GOptionContext *context;
@@ -932,7 +922,7 @@ callback_test_optional_7 (void)
   argv = split_string ("program -td", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (callback_test_optional_string == NULL);
@@ -945,7 +935,7 @@ callback_test_optional_7 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 callback_test_optional_8 (void)
 {
   GOptionContext *context;
@@ -967,7 +957,7 @@ callback_test_optional_8 (void)
   argv = split_string ("program -dt foo.txt", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (callback_test_optional_string);
@@ -980,6 +970,66 @@ callback_test_optional_8 (void)
   g_option_context_free (context);
 }
 
+static void
+callback_test_optional_9 (void)
+{
+  GOptionContext *context;
+  gboolean retval;
+  GError *error = NULL;
+  gchar **argv;
+  int argc;
+  gchar *string = NULL;
+  GOptionEntry entries [] =
+    { { "test", 't', G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_STRING,
+                &string, NULL, NULL },
+      { NULL } };
+
+  context = g_option_context_new (NULL);
+  g_option_context_add_main_entries (context, entries, NULL);
+
+  /* Now try parsing */
+  argv = split_string ("program -t", &argc);
+
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_assert_error (error, G_OPTION_ERROR, G_OPTION_ERROR_BAD_VALUE);
+  g_assert (!retval);
+  g_assert (string == NULL);
+
+  g_error_free (error);
+  g_strfreev (argv);
+  g_option_context_free (context);
+}
+
+static void
+callback_test_optional_10 (void)
+{
+  GOptionContext *context;
+  gboolean retval;
+  GError *error = NULL;
+  gchar **argv;
+  int argc;
+  gchar *string = NULL;
+  GOptionEntry entries [] =
+    { { "test", 't', G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_STRING,
+                &string, NULL, NULL },
+      { NULL } };
+
+  context = g_option_context_new (NULL);
+  g_option_context_add_main_entries (context, entries, NULL);
+
+  /* Now try parsing */
+  argv = split_string ("program --test", &argc);
+
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_assert_error (error, G_OPTION_ERROR, G_OPTION_ERROR_BAD_VALUE);
+  g_assert (!retval);
+  g_assert (string == NULL);
+
+  g_error_free (error);
+  g_strfreev (argv);
+  g_option_context_free (context);
+}
+
 static GPtrArray *callback_remaining_args;
 static gboolean
 callback_remaining_test1_callback (const gchar *option_name, const gchar *value,
@@ -989,7 +1039,7 @@ callback_remaining_test1_callback (const gchar *option_name, const gchar *value,
 	return TRUE;
 }
 
-void
+static void
 callback_remaining_test1 (void)
 {
   GOptionContext *context;
@@ -1009,7 +1059,7 @@ callback_remaining_test1 (void)
   argv = split_string ("program foo.txt blah.txt", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (callback_remaining_args->len == 2);
@@ -1099,7 +1149,7 @@ callback_returns_false (void)
 }
 
 
-void
+static void
 ignore_test1 (void)
 {
   GOptionContext *context;
@@ -1121,7 +1171,7 @@ ignore_test1 (void)
   argv_copy = copy_stringv (argv, argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1134,7 +1184,7 @@ ignore_test1 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 ignore_test2 (void)
 {
   GOptionContext *context;
@@ -1155,7 +1205,7 @@ ignore_test2 (void)
   argv = split_string ("program -test", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1167,7 +1217,7 @@ ignore_test2 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 ignore_test3 (void)
 {
   GOptionContext *context;
@@ -1189,7 +1239,7 @@ ignore_test3 (void)
   argv_copy = copy_stringv (argv, argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1206,7 +1256,7 @@ ignore_test3 (void)
 }
 
 void
-array_test1 (void)
+static array_test1 (void)
 {
   GOptionContext *context;
   gboolean retval;
@@ -1224,7 +1274,7 @@ array_test1 (void)
   argv = split_string ("program --test foo --test bar", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1238,7 +1288,7 @@ array_test1 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 add_test1 (void)
 {
   GOptionContext *context;
@@ -1257,28 +1307,7 @@ add_test1 (void)
   g_option_context_free (context);
 }
 
-void
-empty_test1 (void)
-{
-  GOptionContext *context;
-  GOptionEntry entries [] =
-    { { NULL } };
-  char *prgname;
-
-  g_set_prgname (NULL);
-  context = g_option_context_new (NULL);
-
-  g_option_context_add_main_entries (context, entries, NULL);
-  
-  g_option_context_parse (context, NULL, NULL, NULL);
-
-  prgname = g_get_prgname ();
-  g_assert (prgname && strcmp (prgname, "<unknown>") == 0);
-  
-  g_option_context_free (context);
-}
-
-void
+static void
 empty_test2 (void)
 {
   GOptionContext *context;
@@ -1289,7 +1318,7 @@ empty_test2 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 empty_test3 (void)
 {
   GOptionContext *context;
@@ -1306,7 +1335,7 @@ empty_test3 (void)
 }
 
 /* check that non-option arguments are left in argv by default */
-void
+static void
 rest_test1 (void)
 {
   GOptionContext *context;
@@ -1326,7 +1355,7 @@ rest_test1 (void)
   argv = split_string ("program foo --test bar", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1341,7 +1370,7 @@ rest_test1 (void)
 }
 
 /* check that -- works */
-void
+static void
 rest_test2 (void)
 {
   GOptionContext *context;
@@ -1361,7 +1390,7 @@ rest_test2 (void)
   argv = split_string ("program foo --test -- -bar", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1377,7 +1406,7 @@ rest_test2 (void)
 }
 
 /* check that -- stripping works */
-void
+static void
 rest_test2a (void)
 {
   GOptionContext *context;
@@ -1397,7 +1426,7 @@ rest_test2a (void)
   argv = split_string ("program foo --test -- bar", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1411,7 +1440,7 @@ rest_test2a (void)
   g_option_context_free (context);
 }
 
-void
+static void
 rest_test2b (void)
 {
   GOptionContext *context;
@@ -1432,7 +1461,7 @@ rest_test2b (void)
   argv = split_string ("program foo --test -bar --", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1446,7 +1475,7 @@ rest_test2b (void)
   g_option_context_free (context);
 }
 
-void
+static void
 rest_test2c (void)
 {
   GOptionContext *context;
@@ -1466,7 +1495,7 @@ rest_test2c (void)
   argv = split_string ("program --test foo -- bar", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1480,7 +1509,7 @@ rest_test2c (void)
   g_option_context_free (context);
 }
 
-void
+static void
 rest_test2d (void)
 {
   GOptionContext *context;
@@ -1500,7 +1529,7 @@ rest_test2d (void)
   argv = split_string ("program --test -- -bar", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1516,7 +1545,7 @@ rest_test2d (void)
 
 
 /* check that G_OPTION_REMAINING collects non-option arguments */
-void
+static void
 rest_test3 (void)
 {
   GOptionContext *context;
@@ -1537,7 +1566,7 @@ rest_test3 (void)
   argv = split_string ("program foo --test bar", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1554,7 +1583,7 @@ rest_test3 (void)
 
 
 /* check that G_OPTION_REMAINING and -- work together */
-void
+static void
 rest_test4 (void)
 {
   GOptionContext *context;
@@ -1575,7 +1604,7 @@ rest_test4 (void)
   argv = split_string ("program foo --test -- -bar", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1591,7 +1620,7 @@ rest_test4 (void)
 }
 
 /* test that G_OPTION_REMAINING works with G_OPTION_ARG_FILENAME_ARRAY */
-void
+static void
 rest_test5 (void)
 {
   GOptionContext *context;
@@ -1612,7 +1641,7 @@ rest_test5 (void)
   argv = split_string ("program foo --test bar", &argc);
   
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   /* Check array */
@@ -1627,7 +1656,7 @@ rest_test5 (void)
   g_option_context_free (context);
 }
 
-void
+static void
 unknown_short_test (void)
 {
   GOptionContext *context;
@@ -1653,7 +1682,8 @@ unknown_short_test (void)
 }
 
 /* test that lone dashes are treated as non-options */
-void lonely_dash_test (void)
+static void
+lonely_dash_test (void)
 {
   GOptionContext *context;
   gboolean retval;
@@ -1669,7 +1699,7 @@ void lonely_dash_test (void)
   argv = split_string ("program -", &argc);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
-  assert_no_error (error);
+  g_assert_no_error (error);
   g_assert (retval);
 
   g_assert (argv[1] && strcmp (argv[1], "-") == 0);
@@ -1678,7 +1708,7 @@ void lonely_dash_test (void)
   g_option_context_free (context);
 }
 
-void
+static void
 missing_arg_test (void)
 {
   GOptionContext *context;
@@ -1726,7 +1756,7 @@ static gboolean cb (const gchar  *option_name,
   return TRUE;
 }
 
-void
+static void
 dash_arg_test (void)
 {
   GOptionContext *context;
@@ -1864,6 +1894,67 @@ test_error_hook (void)
   g_option_context_free (context);
 }
 
+static void
+flag_reverse_string (void)
+{
+  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDERR))
+    {
+      GOptionContext *context;
+      gchar *arg = NULL;
+      GOptionEntry entries [] =
+        { { "test", 't', G_OPTION_FLAG_REVERSE, G_OPTION_ARG_STRING, &arg, NULL, NULL },
+          { NULL } };
+      gchar **argv;
+      gint argc;
+      gboolean retval;
+      GError *error = NULL;
+
+      context = g_option_context_new (NULL);
+      g_option_context_add_main_entries (context, entries, NULL);
+
+      argv = split_string ("program --test bla", &argc);
+
+      retval = g_option_context_parse (context, &argc, &argv, &error);
+      g_assert (retval == FALSE);
+      g_clear_error (&error);
+      g_strfreev (argv);
+      g_option_context_free (context);
+      exit (0);
+    }
+  g_test_trap_assert_failed ();
+  g_test_trap_assert_stderr ("*ignoring reverse flag*");
+}
+
+static void
+flag_optional_int (void)
+{
+  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDERR))
+    {
+      GOptionContext *context;
+      gint arg = 0;
+      GOptionEntry entries [] =
+        { { "test", 't', G_OPTION_FLAG_OPTIONAL_ARG, G_OPTION_ARG_INT, &arg, NULL, NULL },
+          { NULL } };
+      gchar **argv;
+      gint argc;
+      gboolean retval;
+      GError *error = NULL;
+
+      context = g_option_context_new (NULL);
+      g_option_context_add_main_entries (context, entries, NULL);
+
+      argv = split_string ("program --test 5", &argc);
+
+      retval = g_option_context_parse (context, &argc, &argv, &error);
+      g_assert (retval == FALSE);
+      g_clear_error (&error);
+      g_strfreev (argv);
+      g_option_context_free (context);
+      exit (0);
+    }
+  g_test_trap_assert_failed ();
+  g_test_trap_assert_stderr ("*ignoring no-arg, optional-arg or filename flags*");
+}
 int
 main (int   argc,
       char *argv[])
@@ -1881,7 +1972,7 @@ main (int   argc,
   g_test_add_func ("/option/restoration/int", error_test1);
   g_test_add_func ("/option/restoration/string", error_test2);
   g_test_add_func ("/option/restoration/boolean", error_test3);
-  
+
   /* Test that special argument parsing works */
   g_test_add_func ("/option/arg/repetition/int", arg_test1);
   g_test_add_func ("/option/arg/repetition/string", arg_test2);
@@ -1909,19 +2000,20 @@ main (int   argc,
 
   /* Test callback with G_OPTION_REMAINING */
   g_test_add_func ("/option/arg/remaining/callback", callback_remaining_test1);
-  
+
   /* Test callbacks which return FALSE */
   g_test_add_func ("/option/arg/remaining/callback-false", callback_returns_false);
-  
+
   /* Test ignoring options */
   g_test_add_func ("/option/arg/ignore/long", ignore_test1);
   g_test_add_func ("/option/arg/ignore/short", ignore_test2);
   g_test_add_func ("/option/arg/ignore/arg", ignore_test3);
-
   g_test_add_func ("/option/context/add", add_test1);
 
   /* Test parsing empty args */
-  g_test_add_func ("/option/context/empty1", empty_test1);
+  /* Note there used to be an empty1 here, but it effectively moved
+   * to option-argv0.c.
+   */
   g_test_add_func ("/option/context/empty2", empty_test2);
   g_test_add_func ("/option/context/empty3", empty_test3);
 
@@ -1936,6 +2028,10 @@ main (int   argc,
   g_test_add_func ("/option/arg/remaining/separator", rest_test4);
   g_test_add_func ("/option/arg/remaining/array", rest_test5);
 
+  /* Test some invalid flag combinations */
+  g_test_add_func ("/option/arg/reverse-string", flag_reverse_string);
+  g_test_add_func ("/option/arg/optional-int", flag_optional_int);
+
   /* regression tests for individual bugs */
   g_test_add_func ("/option/bug/unknown-short", unknown_short_test);
   g_test_add_func ("/option/bug/lonely-dash", lonely_dash_test);
