@@ -19,7 +19,8 @@
  * if advised of the possibility of such damage.
  */
 
-#define _XOPEN_SOURCE
+#define GLIB_DISABLE_DEPRECATION_WARNINGS
+
 #include <ctype.h>
 #include <errno.h>
 #include <locale.h>
@@ -277,6 +278,8 @@ test_strconcat (void)
   g_assert (str != NULL);
   g_assert_cmpstr (str, ==, GLIB_TEST_STRING GLIB_TEST_STRING GLIB_TEST_STRING);
   g_free (str);
+
+  g_assert (g_strconcat (NULL, "bla", NULL) == NULL);
 }
 
 static void
@@ -851,7 +854,7 @@ test_strv_length (void)
 
 static char *locales[] = {"sv_SE", "en_US", "fa_IR", "C", "ru_RU"};
 
-void
+static void
 check_strtod_string (gchar    *number,
 		     double    res,
 		     gboolean  check_end,
@@ -910,6 +913,7 @@ check_strtod_number (gdouble num, gchar *fmt, gchar *str)
 
   for (l = 0; l < G_N_ELEMENTS (locales); l++)
     {
+      setlocale (LC_ALL, locales[l]);
       g_ascii_formatd (buf, G_ASCII_DTOSTR_BUF_SIZE, fmt, num);
       g_assert_cmpstr (buf, ==, str);
     }
@@ -1075,8 +1079,8 @@ test_bounds (void)
 
   file = g_mapped_file_new ("4096-random-bytes", TRUE, NULL);
   after = g_mapped_file_new ("4096-random-bytes", TRUE, NULL);
-  g_mapped_file_free (before);
-  g_mapped_file_free (after);
+  g_mapped_file_unref (before);
+  g_mapped_file_unref (after);
 
   g_assert (file != NULL);
   g_assert_cmpint (g_mapped_file_get_length (file), ==, 4096);
@@ -1210,7 +1214,7 @@ test_bounds (void)
   g_free (tmp2);
   g_free (tmp);
 
-  g_mapped_file_free (file);
+  g_mapped_file_unref (file);
 }
 
 static void
@@ -1239,6 +1243,46 @@ test_strip_context (void)
   g_assert (s == msgval + 7);
 }
 
+static void
+test_strerror (void)
+{
+  gint i;
+  const gchar *str;
+
+  for (i = 1; i < 100; i++)
+    {
+      str = g_strerror (i);
+      g_assert (str != NULL);
+      g_assert (g_utf8_validate (str, -1, NULL));
+    }
+}
+
+static void
+test_strsignal (void)
+{
+  gint i;
+  const gchar *str;
+
+  for (i = 1; i < 20; i++)
+    {
+      str = g_strsignal (i);
+      g_assert (str != NULL);
+      g_assert (g_utf8_validate (str, -1, NULL));
+    }
+}
+
+static void
+test_strup (void)
+{
+  gchar *s;
+
+  s = g_strdup ("lower");
+  g_assert_cmpstr (g_strup (s), ==, "LOWER");
+  g_assert_cmpstr (g_strdown (s), ==, "lower");
+  g_assert (g_strcasecmp ("lower", "LOWER") == 0);
+  g_free (s);
+}
+
 int
 main (int   argc,
       char *argv[])
@@ -1269,6 +1313,9 @@ main (int   argc,
   g_test_add_func ("/strfuncs/strtoull-strtoll", test_strtoll);
   g_test_add_func ("/strfuncs/bounds-check", test_bounds);
   g_test_add_func ("/strfuncs/strip-context", test_strip_context);
+  g_test_add_func ("/strfuncs/strerror", test_strerror);
+  g_test_add_func ("/strfuncs/strsignal", test_strsignal);
+  g_test_add_func ("/strfuncs/strup", test_strup);
 
   return g_test_run();
 }
