@@ -205,7 +205,7 @@ struct _GParamSpec
 {
   GTypeInstance  g_type_instance;
 
-  gchar         *name;
+  const gchar   *name;          /* interned string */
   GParamFlags    flags;
   GType		 value_type;
   GType		 owner_type;	/* class or interface using this property */
@@ -228,7 +228,7 @@ struct _GParamSpec
  *  g_param_value_set_default().
  * @value_validate: Ensures that the contents of @value comply with the 
  *  specifications set out by this type (optional), see 
- *  g_param_value_set_validate().
+ *  g_param_value_validate().
  * @values_cmp: Compares @value1 with @value2 according to this type
  *  (recommended, the default is memcmp()), see g_param_values_cmp().
  * 
@@ -263,7 +263,7 @@ struct _GParamSpecClass
  * The <structname>GParameter</structname> struct is an auxiliary structure used
  * to hand parameter name/value pairs to g_object_newv().
  */
-struct _GParameter /* auxillary structure for _setv() variants */
+struct _GParameter /* auxiliary structure for _setv() variants */
 {
   const gchar *name;
   GValue       value;
@@ -313,8 +313,9 @@ GParamSpec*     g_value_dup_param               (const GValue  *value);
 void           g_value_take_param               (GValue        *value,
 					         GParamSpec    *param);
 #ifndef G_DISABLE_DEPRECATED
+GLIB_DEPRECATED_FOR(g_value_take_param)
 void           g_value_set_param_take_ownership (GValue        *value,
-					         GParamSpec    *param);
+                                                 GParamSpec    *param);
 #endif
 
 /* --- convenience functions --- */
@@ -331,7 +332,7 @@ typedef struct _GParamSpecTypeInfo GParamSpecTypeInfo;
  *  g_param_value_set_default().
  * @value_validate: Ensures that the contents of @value comply with the 
  *  specifications set out by @pspec (optional), see 
- *  g_param_value_set_validate().
+ *  g_param_value_validate().
  * @values_cmp: Compares @value1 with @value2 according to @pspec 
  *  (recommended, the default is memcmp()), see g_param_values_cmp().
  * 
