@@ -1,3 +1,4 @@
+#define GLIB_DISABLE_DEPRECATION_WARNINGS
 #include <glib-object.h>
 
 static void
@@ -5,7 +6,7 @@ test_param_value (void)
 {
   GParamSpec *p, *p2;
   GParamSpec *pp;
-  GValue value = { 0, };
+  GValue value = G_VALUE_INIT;
 
   g_value_init (&value, G_TYPE_PARAM);
   g_assert (G_VALUE_HOLDS_PARAM (&value));
@@ -65,7 +66,7 @@ static void
 test_param_validate (void)
 {
   GParamSpec *p;
-  GValue value = { 0, };
+  GValue value = G_VALUE_INIT;
 
   p = g_param_spec_int ("my-int", "My Int", "Blurb", 0, 20, 10, G_PARAM_READWRITE);
 
@@ -110,8 +111,8 @@ static void
 test_param_convert (void)
 {
   GParamSpec *p;
-  GValue v1 = { 0, };
-  GValue v2 = { 0, };
+  GValue v1 = G_VALUE_INIT;
+  GValue v2 = G_VALUE_INIT;
 
   p = g_param_spec_int ("my-int", "My Int", "Blurb", 0, 20, 10, G_PARAM_READWRITE);
   g_value_init (&v1, G_TYPE_UINT);
@@ -132,8 +133,8 @@ test_param_convert (void)
 static void
 test_value_transform (void)
 {
-  GValue src = { 0, };
-  GValue dest = { 0, };
+  GValue src = G_VALUE_INIT;
+  GValue dest = G_VALUE_INIT;
 
 #define CHECK_INT_CONVERSION(type, getter, value)                       \
   g_assert (g_value_type_transformable (G_TYPE_INT, type));             \
@@ -145,8 +146,15 @@ test_value_transform (void)
   g_value_unset (&src);                                                 \
   g_value_unset (&dest);
 
-  CHECK_INT_CONVERSION(G_TYPE_CHAR, char, -124)
+  /* Keep a check for an integer in the range of 0-127 so we're
+   * still testing g_value_get_char().  See
+   * https://bugzilla.gnome.org/show_bug.cgi?id=659870
+   * for why it is broken.
+   */
   CHECK_INT_CONVERSION(G_TYPE_CHAR, char, 124)
+
+  CHECK_INT_CONVERSION(G_TYPE_CHAR, schar, -124)
+  CHECK_INT_CONVERSION(G_TYPE_CHAR, schar, 124)
   CHECK_INT_CONVERSION(G_TYPE_UCHAR, uchar, 0)
   CHECK_INT_CONVERSION(G_TYPE_UCHAR, uchar, 255)
   CHECK_INT_CONVERSION(G_TYPE_INT, int, -12345)
@@ -378,9 +386,9 @@ test_value_transform (void)
   g_value_init (&src, G_TYPE_STRING);
   g_value_init (&dest, G_TYPE_CHAR);
   g_value_set_static_string (&src, "bla");
-  g_value_set_char (&dest, 'c');
+  g_value_set_schar (&dest, 'c');
   g_assert (!g_value_transform (&src, &dest));
-  g_assert_cmpint (g_value_get_char (&dest), ==, 'c');
+  g_assert_cmpint (g_value_get_schar (&dest), ==, 'c');
   g_value_unset (&src);
   g_value_unset (&dest);
 }
